@@ -51,7 +51,7 @@ def pareto_graph(variable, salida='tabla'):
     else:
         return (pareto)
 
-def fis_bs_pareto_graph(variable, salida='grafico'):
+def fis_bs_pareto_graph(variable, title_show = False, salida='grafico'):
     #Ordenar en descendente y pasar a dataframe
     pareto = variable.sort_values(ascending=False).to_frame()
     #Cambiar el nombre a la variable
@@ -84,8 +84,9 @@ def fis_bs_pareto_graph(variable, salida='grafico'):
         ax.axvline(nearest, color="#D6D7D9", alpha=0.3)
         ax.text(nearest + 2, 0, "%.1f %%" % (nearest))
         ax.axhline(80, color="#D6D7D9", alpha=0.3, linestyle='dotted')
-        ax.set_title("Pareto graph for '%s' by '%s'" %
-                     (variable.name, variable.index.name))
+        if title_show:
+            ax.set_title("Pareto graph for '%s' by '%s'" %
+                         (variable.name, variable.index.name))
         ax.fill_between([ini, nearest, nearest, ini], [0, 0, 100, 100],
                         alpha=0.3,
                         color="#D6D7D9")
@@ -351,8 +352,8 @@ def fis_bs_mekko(ynp_values,xnp_values,x_label,figsize=(12,7),color1='#97ACCF',c
         temp += i
         adjusted_x.append(temp)
     # Marimekko chart
-    plt.bar(adjusted_x, y, width=width, align='edge', edgecolor='black',color=color1)
-    plt.bar(adjusted_x, np.ones(len(y))-y, bottom=y, width=width, align='edge', edgecolor='black',color=color2)
+    plt.bar(adjusted_x, y, width=width, align='edge', edgecolor='black',color=color1,alpha=0.7)
+    plt.bar(adjusted_x, np.ones(len(y))-y, bottom=y, width=width, align='edge', edgecolor='black',color=color2,alpha=0.7)
     # x and y ticks (%)
     ax.set_yticks([0, 0.25, 0.5, 0.75, 1])
     ax.set_yticklabels(['0%', '25%', '50%', '75%', '100%'])
@@ -366,9 +367,66 @@ def fis_bs_mekko(ynp_values,xnp_values,x_label,figsize=(12,7),color1='#97ACCF',c
     axy.set_xticklabels(x_label, fontsize=xticks_size)
     ax.set_ylabel(label_y)
     ax.set_xlabel(label_x)
+    ax.spines.right.set_visible(True)
     plt.title(title,
               loc='left', fontsize=title_size)
     ax.legend([legend1,legend2], 
                ncol=2, loc='upper left', fontsize=legend_size,
                    frameon=False, bbox_to_anchor=(0,1.25))
     return f, ax
+
+def fis_bs_sankey(source, target, value,labels_sr,labels_tr,label_show=False, opacity_ins=0.5):
+    opacity = str(opacity_ins)
+    color_rgb = []
+    color_rgb.append('rgba(151, 172, 207, %s)'%(opacity))
+    color_rgb.append('rgba(110, 127, 128, %s)'%(opacity))
+    color_rgb.append('rgba(0, 105, 148, %s)'%(opacity))
+    color_rgb.append('rgba(83, 104, 114, %s)'%(opacity))
+    color_rgb.append('rgba(201, 239, 254, %s)'%(opacity))
+    color_rgb.append('rgba(54, 69, 79, %s)'%(opacity))
+    color_rgb.append('rgba(178, 203, 245, %s)'%(opacity))
+    color_rgb.append('rgba(42, 192, 251, %s)'%(opacity))
+    color_rgb.append('rgba(137, 207, 240, %s)'%(opacity))
+    color_rgb.append('rgba(95, 108, 130, %s)'%(opacity))
+    
+    if label_show:
+        color_label='black'
+    else:
+        color_label="rgba(0,0,0,0)"
+
+    config = {
+      'displayModeBar': False,
+    }
+    
+    color_node = []
+    
+    for i in range(0,len(labels_sr)):
+        color_node.append(color_rgb[i])
+        
+    for i in range(0,len(labels_sr)):
+        color_node.append('white')
+
+    labels=labels_sr + labels_tr
+    
+    color_link = []
+    # link color
+    for i in source:
+        color_link.append(color_rgb[i])
+
+    fig = go.Figure(data=[go.Sankey(
+        node = dict(
+          pad = 20,
+          thickness = 1,
+          line = dict(color = "black", width = 0),
+          label = labels,
+          color = color_node
+        ),
+        textfont=dict(color=color_label, size=12),
+        link = dict(
+          source = source, # indices correspond to labels, eg A1, A2, A1, B1, ...
+          target = target,
+          value = value,
+          color = color_link
+      ))])
+    img_bytes = fig.to_image(format="png",height=600,width=800)
+    return Image(img_bytes)
\ No newline at end of file
